//
// I2C 7-Segment LED module access sample program
//

#include "p18cxxx.h"					// Microchip C18 library
#include "i2c.h"                        // C18 Peripheral Library

//
// Configuration bits
//
#pragma config CPUDIV = NOCLKDIV		// 48MHz
#pragma config USBDIV = OFF				// No div
#pragma config FOSC   = HS				// Xtal=12MHz
#pragma config PLLEN  = ON				// Xtal * 4
#pragma config FCMEN  = OFF
#pragma config IESO   = OFF
#pragma config PWRTEN = OFF
#pragma config BOREN  = OFF
#pragma config BORV   = 19
//#pragma config VREGEN = ON
#pragma config WDTEN  = OFF
#pragma config WDTPS  = 1024			// 4sec
#pragma config MCLRE  = OFF
#pragma config HFOFST = OFF
#pragma config STVREN = ON
#pragma config LVP    = OFF
#pragma config XINST  = OFF
#pragma config BBSIZ  = OFF
#pragma config CP0    = OFF
#pragma config CP1    = OFF
#pragma config CPB    = OFF
#pragma config WRT0   = OFF
#pragma config WRT1   = OFF
#pragma config WRTB   = OFF
#pragma config WRTC   = OFF
#pragma config EBTR0  = OFF
#pragma config EBTR1  = OFF
#pragma config EBTRB  = OFF       

// Enable Bootloader
extern void _startup (void);        // See c018i.c in your C18 compiler dir
#pragma code REMAPPED_RESET_VECTOR = 0x1000
void _reset (void){
	    _asm goto _startup _endasm
}
#pragma code						// Default


//
//	Sample code
//
void main(void){
	unsigned char sad;
	unsigned char buf[9];
	int i;
	int j;

	// Enable internal pull-up register
	WPUA               = 0;				// Internal pullup default all off
	WPUB               = 0;				//
	WPUBbits.WPUB4     = 1;				// I2C SDA(RB4) pullup
	WPUBbits.WPUB6     = 1;				// I2C SCL(RB6) pullup
	INTCON2bits.RABPU  = 0;				// Enable pullup

	// LED Module command
	sad = 0x09;							// Slave address
	buf[0] = 0x00;						// Write command
	buf[1] = 0x38;						// "L"
	buf[2] = 0x79;						// "E"
	buf[3] = 0x5e;						// "d"
	buf[4] = 0x00;						// " "
	buf[5] = 0x38;						// "L"
	buf[6] = 0x79;						// "E"
	buf[7] = 0x5e;						// "d"
	buf[8] = 0x00;						// " "

	// Open I2C
	OpenI2C(MASTER, SLEW_OFF);
	SSPADD = 0x77;						// FOSC=48MHz SCL->100KHz

	for(j = 0; j < 256; j++){
		buf[4] = j;
		buf[8] = j;

		// Send message to I2C bus
		StartI2C();						// Start condition
		WriteI2C(sad << 1);				// Slave addreaa + write bit
		for(i = 0; i < sizeof(buf); i++) {
			WriteI2C(buf[i]);			// Data
		}
		StopI2C();						// Stop condition

		// Wait
		for(i = 0; i < 30000; i++);
	}

	// Close I2C
	CloseI2C();

	for(;;);
}
